@@ -9,6 +9,34 @@ import (
 	. "github.com/openshift/cluster-logging-operator/test/matchers"
 )
 
+var _ = Describe("outputLabelConf buffer tuning", func() {
+	var (
+		forwarderSpec *loggingv1.ForwarderSpec
+		conf          *outputLabelConf
+	)
+	BeforeEach(func() {
+		forwarderSpec = &loggingv1.ForwarderSpec{
+			Fluentd: &loggingv1.FluentdForwarderSpec{
+				Buffer: &loggingv1.FluentdBufferSpec{},
+			},
+		}
+		conf = &outputLabelConf{
+			forwarder: forwarderSpec,
+		}
+	})
+	Context("#RetryTimeout", func() {
+		It("should return the default when not configured", func() {
+			Expect(conf.RetryTimeout()).To(Equal("retry_timeout " + defaultRetryTimeout))
+		})
+		It("should use the spec'd value when configured", func() {
+			forwarderSpec.Fluentd.Buffer.RetryTimeout = "72h"
+			Expect(conf.RetryTimeout()).To(Equal("retry_timeout 72h"))
+		})
+
+	})
+
+})
+
 var _ = Describe("Generating fluentd config", func() {
 	var (
 		outputs              []loggingv1.OutputSpec
@@ -103,11 +131,10 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_mode interval
                 flush_interval 1s
                 flush_thread_count 2
-                flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
                 retry_max_interval 60s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -146,11 +173,10 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_mode interval
                 flush_interval 1s
                 flush_thread_count 2
-                flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
                 retry_max_interval 60s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -229,11 +255,10 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_mode interval
                 flush_interval 1s
                 flush_thread_count 2
-                flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
                 retry_max_interval 60s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -272,11 +297,10 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_mode interval
                 flush_interval 1s
                 flush_thread_count 2
-                flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
                 retry_max_interval 60s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -337,13 +361,11 @@ var _ = Describe("Generating fluentd config", func() {
                 @type file
                 path '/var/lib/fluentd/retry_other_elasticsearch'
                 flush_mode immediate
-                flush_interval 2s
                 flush_thread_count 4
-                flush_at_shutdown true
                 retry_type periodic
                 retry_wait 2s
                 retry_max_interval 600s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size 512m
                 chunk_limit_size 256m
@@ -380,13 +402,11 @@ var _ = Describe("Generating fluentd config", func() {
                 @type file
                 path '/var/lib/fluentd/other_elasticsearch'
                 flush_mode immediate
-                flush_interval 2s
                 flush_thread_count 4
-                flush_at_shutdown true
                 retry_type periodic
                 retry_wait 2s
                 retry_max_interval 600s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size 512m
                 chunk_limit_size 256m
@@ -436,12 +456,11 @@ var _ = Describe("Generating fluentd config", func() {
             chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
             flush_mode interval
             flush_interval 5s
-            flush_at_shutdown true
-            flush_thread_count 2
-            retry_type exponential_backoff
+            flush_thread_count 2            
+			retry_type exponential_backoff
             retry_wait 1s
             retry_max_interval 60s
-            retry_forever true
+            retry_timeout 60m
             # the systemd journald 0.0.8 input plugin will just throw away records if the buffer
             # queue limit is hit - 'block' will halt further reads and keep retrying to flush the
             # buffer to the remote - default is 'block' because in_tail handles that case
@@ -477,13 +496,11 @@ var _ = Describe("Generating fluentd config", func() {
           total_limit_size 512m
           chunk_limit_size 256m
           flush_mode immediate
-          flush_interval 2s
-          flush_at_shutdown true
           flush_thread_count 4
           retry_type periodic
           retry_wait 2s
           retry_max_interval 600s
-          retry_forever true
+          retry_timeout 60m
           # the systemd journald 0.0.8 input plugin will just throw away records if the buffer
           # queue limit is hit - 'block' will halt further reads and keep retrying to flush the
           # buffer to the remote - default is 'block' because in_tail handles that case
@@ -548,17 +565,19 @@ var _ = Describe("Generating fluentd config", func() {
                 keep_alive_idle 75
                 keep_alive_cnt 9
                 keep_alive_intvl 7200
+			<format>
+			  @type json
+			</format>
             <buffer >
                 @type file
                 path '/var/lib/fluentd/syslog_receiver'
                 flush_mode interval
                 flush_interval 1s
                 flush_thread_count 2
-                flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
                 retry_max_interval 60s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -602,17 +621,18 @@ var _ = Describe("Generating fluentd config", func() {
                 keep_alive_idle 75
                 keep_alive_cnt 9
                 keep_alive_intvl 7200
+			<format>
+			  @type json
+			</format>
             <buffer >
                 @type file
                 path '/var/lib/fluentd/syslog_receiver'
                 flush_mode immediate
-                flush_interval 2s
                 flush_thread_count 4
-                flush_at_shutdown true
                 retry_type periodic
                 retry_wait 2s
                 retry_max_interval 600s
-                retry_forever true
+                retry_timeout 60m
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size 512m
                 chunk_limit_size 256m
@@ -661,11 +681,10 @@ var _ = Describe("Generating fluentd config", func() {
                flush_mode interval
                flush_interval 1s
                flush_thread_count 2
-               flush_at_shutdown true
                retry_type exponential_backoff
                retry_wait 1s
                retry_max_interval 60s
-               retry_forever true
+               retry_timeout 60m
                queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -694,13 +713,11 @@ var _ = Describe("Generating fluentd config", func() {
                @type file
                path '/var/lib/fluentd/kafka_receiver'
                flush_mode immediate
-               flush_interval 2s
                flush_thread_count 4
-               flush_at_shutdown true
                retry_type periodic
                retry_wait 2s
                retry_max_interval 600s
-               retry_forever true
+               retry_timeout 60m
                queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                total_limit_size 512m
                chunk_limit_size 256m
