@@ -7,11 +7,13 @@ var templateRegistry = []string{
 	inputSourceHostAuditTemplate,
 	inputSourceK8sAuditTemplate,
 	inputSourceOpenShiftAuditTemplate,
+	inputSourceOVNAuditTemplate,
 	fluentConfTemplate,
 	pipelineToOutputCopyTemplate,
 	sourceToPipelineCopyTemplate,
 	inputSelectorToPipelineTemplate,
 	inputSelectorBlockTemplate,
+	outputLabelConfCloudwatch,
 	outputLabelConfTemplate,
 	outputLabelConfNocopyTemplate,
 	outputLabelConfNoretryTemplate,
@@ -21,6 +23,7 @@ var templateRegistry = []string{
 	storeSyslogTemplateOld,
 	storeSyslogTemplate,
 	storeKafkaTemplate,
+	outputLabelLokiTemplate,
 }
 
 const fluentConfTemplate = `{{- define "fluentConf" -}}
@@ -57,6 +60,13 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
 # excluding prometheus_tail_monitor
 # since it leaks namespace/pod info
 # via file paths
+# including new plugin which publishes log_collected_bytes_total
+<source>
+  @type collected_tail_monitor
+  <labels>
+    hostname ${hostname}
+  </labels>
+</source>
 
 # This is considered experimental by the repo
 <source>
@@ -141,11 +151,19 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
 
   ## filters
   <filter journal>
-    @type grep
-    <exclude>
+   @type grep
+   <exclude>
       key PRIORITY
       pattern ^7$
-    </exclude>
+   </exclude>
+  </filter>
+
+  <filter ovn-audit.log**>
+    @type record_modifier
+    <record>
+      @timestamp ${DateTime.parse(record['message'].split('|')[0]).rfc3339(6)}
+      level ${record['message'].split('|')[3].downcase}
+    </record>
   </filter>
 
   <match journal>
@@ -262,14 +280,12 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
     @type record_modifier
     <record>
       k8s_audit_level ${record['level']}
-      level info
     </record>
   </filter>
   <filter openshift-audit.log**>
     @type record_modifier
     <record>
       openshift_audit_level ${record['level']}
-      level info
     </record>
   </filter>
 
@@ -290,6 +306,22 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
     undefined_dot_replace_char 'UNUSED'
     undefined_max_num_fields '-1'
     process_kubernetes_events 'false'
+    <level>
+      name warn
+      match 'Warning|WARN|W[0-9]+|level=warn|Value:warn|"level":"warn"'
+    </level>
+    <level>
+      name info
+      match 'Info|INFO|I[0-9]+|level=info|Value:info|"level":"info"'
+    </level>
+    <level>
+      name error
+      match 'Error|ERROR|E[0-9]+|level=error|Value:error|"level":"error"'
+    </level>
+    <level>
+      name debug
+      match 'Debug|DEBUG|D[0-9]+|level=debug|Value:debug|"level":"debug"'
+    </level>
     <formatter>
       tag "system.var.log**"
       type sys_var_log
@@ -306,7 +338,7 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
       remove_keys 'log,stream,MESSAGE,_SOURCE_REALTIME_TIMESTAMP,__REALTIME_TIMESTAMP,CONTAINER_ID,CONTAINER_ID_FULL,CONTAINER_NAME,PRIORITY,_BOOT_ID,_CAP_EFFECTIVE,_CMDLINE,_COMM,_EXE,_GID,_HOSTNAME,_MACHINE_ID,_PID,_SELINUX_CONTEXT,_SYSTEMD_CGROUP,_SYSTEMD_SLICE,_SYSTEMD_UNIT,_TRANSPORT,_UID,_AUDIT_LOGINUID,_AUDIT_SESSION,_SYSTEMD_OWNER_UID,_SYSTEMD_SESSION,_SYSTEMD_USER_UNIT,CODE_FILE,CODE_FUNCTION,CODE_LINE,ERRNO,MESSAGE_ID,RESULT,UNIT,_KERNEL_DEVICE,_KERNEL_SUBSYSTEM,_UDEV_SYSNAME,_UDEV_DEVNODE,_UDEV_DEVLINK,SYSLOG_FACILITY,SYSLOG_IDENTIFIER,SYSLOG_PID'
     </formatter>
     <formatter>
-      tag "kubernetes.var.log.containers.eventrouter-** kubernetes.var.log.containers.cluster-logging-eventrouter-** k8s-audit.log** openshift-audit.log**"
+      tag "kubernetes.var.log.containers.eventrouter-** kubernetes.var.log.containers.cluster-logging-eventrouter-** k8s-audit.log** openshift-audit.log** ovn-audit.log**"
       type k8s_json_file
       remove_keys log,stream,CONTAINER_ID_FULL,CONTAINER_NAME
       process_kubernetes_events 'true'
@@ -324,7 +356,7 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
     </elasticsearch_index_name>
     <elasticsearch_index_name>
       enabled 'true'
-      tag "linux-audit.log** k8s-audit.log** openshift-audit.log**"
+      tag "linux-audit.log** k8s-audit.log** openshift-audit.log** ovn-audit.log**"
       name_type static
       static_index_name audit-write
     </elasticsearch_index_name>
@@ -362,7 +394,7 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
     @type null
 {{- end}}
   </match>
-  <match linux-audit.log** k8s-audit.log** openshift-audit.log**>
+  <match linux-audit.log** k8s-audit.log** openshift-audit.log** ovn-audit.log**>
 {{- if .CollectAuditLogs }}
     @type relabel
     @label @_AUDIT
@@ -426,7 +458,7 @@ const inputSourceJournalTemplate = `{{- define "inputSourceJournalTemplate" -}}
     persistent true
     # NOTE: if this does not end in .json, fluentd will think it
     # is the name of a directory - see fluentd storage_local.rb
-    path '/var/log/journal_pos.json'
+    path '/var/lib/fluentd/pos/journal_pos.json'
   </storage>
   matches "#{ENV['JOURNAL_FILTERS_JSON'] || '[]'}"
   tag journal
@@ -441,7 +473,7 @@ const inputSourceContainerTemplate = `{{- define "inputSourceContainerTemplate"
   @id container-input
   path "/var/log/containers/*.log"
   exclude_path ["/var/log/containers/{{.CollectorPodNamePrefix}}-*_{{.LoggingNamespace}}_*.log", "/var/log/containers/{{.LogStorePodNamePrefix}}-*_{{.LoggingNamespace}}_*.log", "/var/log/containers/{{.VisualizationPodNamePrefix}}-*_{{.LoggingNamespace}}_*.log"]
-  pos_file "/var/log/es-containers.log.pos"
+  pos_file "/var/lib/fluentd/pos/es-containers.log.pos"
   refresh_interval 5
   rotate_wait 5
   tag kubernetes.*
@@ -471,9 +503,8 @@ const inputSourceHostAuditTemplate = `{{- define "inputSourceHostAuditTemplate"
   @type tail
   @id audit-input
   @label @MEASURE
-  path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
-  pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
-  refresh_interval 5
+  path "/var/log/audit/audit.log"
+  pos_file "/var/lib/fluentd/pos/audit.log.pos"
   tag linux-audit.log
   <parse>
     @type viaq_host_audit
@@ -487,16 +518,11 @@ const inputSourceK8sAuditTemplate = `{{- define "inputSourceK8sAuditTemplate" -}
   @type tail
   @id k8s-audit-input
   @label @MEASURE
-  path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
-  pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
-  refresh_interval 5
+  path "/var/log/kube-apiserver/audit.log"
+  pos_file "/var/lib/fluentd/pos/kube-apiserver.audit.log.pos"
   tag k8s-audit.log
   <parse>
     @type json
-    time_key requestReceivedTimestamp
-    # In case folks want to parse based on the requestReceivedTimestamp key
-    keep_time_key true
-    time_format %Y-%m-%dT%H:%M:%S.%N%z
   </parse>
 </source>
 {{- end}}`
@@ -508,21 +534,40 @@ const inputSourceOpenShiftAuditTemplate = `{{- define "inputSourceOpenShiftAudit
   @id openshift-audit-input
   @label @MEASURE
   path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
-  pos_file /var/log/oauth-apiserver.audit.log
-  refresh_interval 5
+  pos_file /var/lib/fluentd/pos/oauth-apiserver.audit.log
   tag openshift-audit.log
   <parse>
     @type json
-    time_key requestReceivedTimestamp
-    # In case folks want to parse based on the requestReceivedTimestamp key
-    keep_time_key true
-    time_format %Y-%m-%dT%H:%M:%S.%N%z
+  </parse>
+</source>
+{{- end}}`
+
+const inputSourceOVNAuditTemplate = `{{- define "inputSourceOVNAuditTemplate" }}
+# Openshift Virtual Network (OVN) audit logs
+<source>
+  @type tail
+  @id ovn-audit-input
+  @label @MEASURE
+  path "/var/log/ovn/acl-audit-log.log"
+  pos_file "/var/lib/fluentd/pos/acl-audit-log.pos"
+  tag ovn-audit.log
+  refresh_interval 5
+  rotate_wait 5
+  read_from_head true
+  <parse>
+    @type none
   </parse>
 </source>
 {{- end}}`
 
 const sourceToPipelineCopyTemplate = `{{- define "sourceToPipelineCopyTemplate" -}}
 <label {{sourceTypelabelName .Source}}>
+  <filter **>
+    @type record_modifier
+    <record>
+      log_type {{.Source}}
+    </record>
+  </filter>
   <match **>
     @type copy
 {{- range $index, $pipelineLabel := .PipelineNames }}
@@ -598,12 +643,13 @@ const pipelineToOutputCopyTemplate = `{{- define "pipelineToOutputCopyTemplate"
     hash_value_field structured
     <parse>
       @type json
-	  json_parser oj
+    json_parser oj
     </parse>
   </filter>
   {{ end -}}
   <match **>
     @type copy
+    deep_copy {{.DeepCopy}}
 {{- range $index, $target := .Outputs }}
     <store>
       @type relabel
@@ -614,22 +660,70 @@ const pipelineToOutputCopyTemplate = `{{- define "pipelineToOutputCopyTemplate"
 </label>
 {{- end}}`
 
+const outputLabelConfCloudwatch = `{{- define "outputLabelConfCloudwatch" -}}
+<label {{.LabelName}}>
+  <filter kubernetes.**>
+    @type record_transformer
+	enable_ruby true
+    <record>
+      cw_group_name {{.LogGroupPrefix }}{{.LogGroupName }}
+      cw_stream_name ${tag}
+    </record>
+  </filter>
+  <filter journal **_default_** **_kube-*_** **_openshift-*_** **_openshift_**>
+    @type record_transformer
+	enable_ruby true
+	<record>
+      cw_group_name {{.LogGroupPrefix }}infrastructure
+      cw_stream_name ${record['hostname']}.${tag}
+    </record>
+  </filter>
+  <filter *audit.log>
+    @type record_transformer
+	enable_ruby true
+    <record>
+      cw_group_name {{.LogGroupPrefix }}audit
+      cw_stream_name ${record['hostname']}.${tag}
+    </record>
+  </filter>
+  <match **>
+    @type cloudwatch_logs
+    auto_create_stream true
+    region {{ .Target.Cloudwatch.Region }}
+    log_group_name_key cw_group_name
+	log_stream_name_key cw_stream_name
+    remove_log_stream_name_key true
+    remove_log_group_name_key true
+    auto_create_stream true
+    concurrency 2
+{{- with $path := .SecretPath "aws_access_key_id"}}
+    aws_key_id "#{open('{{ $path }}','r') do |f|f.read.strip end}"
+{{- end}}
+{{- with $path := .SecretPath "aws_secret_access_key"}}
+    aws_sec_key "#{open('{{ $path }}','r') do |f|f.read.strip end}"
+{{- end}}
+    include_time_key true
+    log_rejected_request true
+  </match>
+</label>
+{{- end}}`
+
 const outputLabelConfTemplate = `{{- define "outputLabelConf" -}}
 <label {{.LabelName}}>
   {{- if (.NeedChangeElasticsearchStructuredType)}}
   <filter **>
     @type record_modifier
-	<record>
-	  typeFromKey     ${record.dig({{.GetKeyVal .Target.OutputTypeSpec.Elasticsearch.StructuredTypeKey}})}
-	  hasStructuredTypeName     "{{.Target.OutputTypeSpec.Elasticsearch.StructuredTypeName}}"
-	  viaq_index_name  ${ if !record['structured'].nil? && record['structured'] != {}; if !record['typeFromKey'].nil?; "app-"+record['typeFromKey']+"-write"; elsif record['hasStructuredTypeName'] != ""; "app-"+record['hasStructuredTypeName']+"-write"; else record['viaq_index_name']; end; else record['viaq_index_name']; end;}
-	</record>
-	remove_keys typeFromKey, hasStructuredTypeName
+  <record>
+    typeFromKey     ${record.dig({{.GetKeyVal .Target.OutputTypeSpec.Elasticsearch.StructuredTypeKey}})}
+    hasStructuredTypeName     "{{.Target.OutputTypeSpec.Elasticsearch.StructuredTypeName}}"
+    viaq_index_name  ${ if !record['structured'].nil? && record['structured'] != {}; if !record['typeFromKey'].nil?; "app-"+record['typeFromKey']+"-write"; elsif record['hasStructuredTypeName'] != ""; "app-"+record['hasStructuredTypeName']+"-write"; else record['viaq_index_name']; end; else record['viaq_index_name']; end;}
+  </record>
+  remove_keys typeFromKey, hasStructuredTypeName
   </filter>
   {{- else}}
   <filter **>
     @type record_modifier
-	remove_keys structured
+  remove_keys structured
   </filter>
   {{- end}}
   {{- if .IsElasticSearchOutput}}
@@ -674,10 +768,10 @@ const outputLabelConfNoretryTemplate = `{{- define "outputLabelConfNoRetry" -}}
 const outputLabelConfJsonParseNoretryTemplate = `{{- define "outputLabelConfJsonParseNoRetry" -}}
 <label {{.LabelName}}>
   <filter **>
-	@type parse_json_field
-	json_fields  message
-	merge_json_log false
-	replace_json_log true
+  @type parse_json_field
+  json_fields  message
+  merge_json_log false
+  replace_json_log true
   </filter>
 {{ if .Target.Syslog.AddLogSource }}
   <filter **>
@@ -688,11 +782,18 @@ const outputLabelConfJsonParseNoretryTemplate = `{{- define "outputLabelConfJson
 	  pod_info        ${if record['kubernetes_info'] != nil && record['kubernetes_info'] != {}; "pod_name=" + record['kubernetes_info']['pod_name']; else nil; end}
 	  container_info  ${if record['kubernetes_info'] != nil && record['kubernetes_info'] != {}; "container_name=" + record['kubernetes_info']['container_name']; else nil; end}
 	  msg_key         ${if record.has_key?('message') && record['message'] != nil; record['message']; else nil; end}
-      msg_info        ${if record['msg_key'] != nil && record['msg_key'].is_a?(Hash); require 'json'; "message="+record['message'].to_json; elsif record['msg_key'] != nil; "message="+record['message']; else nil; end}
-      message         ${if record['msg_key'] != nil && record['kubernetes_info'] != nil && record['kubernetes_info'] != {}; record['namespace_info'] + ", " + record['container_info'] + ", " + record['pod_info'] + ", " + record['msg_info']; else record['message']; end}
+	  msg_info        ${if record['msg_key'] != nil && record['msg_key'].is_a?(Hash); require 'json'; "message="+record['message'].to_json; elsif record['msg_key'] != nil; "message="+record['message']; else nil; end}
+	  message         ${if record['msg_key'] != nil && record['kubernetes_info'] != nil && record['kubernetes_info'] != {}; record['namespace_info'] + ", " + record['container_info'] + ", " + record['pod_info'] + ", " + record['msg_info']; else record['message']; end}
+	  systemd_info    ${if record.has_key?('systemd') && record['systemd']['t'].has_key?('PID'); record['systemd']['u']['SYSLOG_IDENTIFIER'] += "[" + record['systemd']['t']['PID'] + "]"; else {}; end}
 	</record>
-	remove_keys kubernetes_info, namespace_info, pod_info, container_info, msg_key, msg_info
+	remove_keys kubernetes_info, namespace_info, pod_info, container_info, msg_key, msg_info, systemd_info
   </filter>
+  # The "infrastructure" stream is splitted into the pod logs and the journal logs.
+  # This match section is for the journal logs to inject the daemon name info into the journal logs only.
+  <match journal.** system.var.log**>
+    @type copy
+{{include .StoreTemplate . "journal_log" | indent 4}}
+  </match>
 {{end -}}
   <match **>
     @type copy
@@ -731,6 +832,9 @@ tls_client_cert_path "{{$path}}"
 {{- with $path := .SecretPathIfFound "ca-bundle.crt"}}
 tls_cert_path "{{$path}}"
 {{- end}}
+{{ with $path := .SecretPathIfFound "passphrase" -}}
+tls_client_private_key_passphrase "#{File.exists?('{{ $path }}') ? open('{{ $path }}','r') do |f|f.read end : ''}"
+{{ end -}} 
 
 {{- end}}
 
@@ -741,13 +845,15 @@ tls_cert_path "{{$path}}"
   total_limit_size {{.TotalLimitSize}}
   chunk_limit_size {{.ChunkLimitSize}}
   flush_mode {{.FlushMode}}
+  {{- if (eq .FlushMode "interval")}}
   flush_interval {{.FlushInterval}}
-  flush_at_shutdown true
+  {{- end}}
+
   flush_thread_count {{.FlushThreadCount}}
   retry_type {{.RetryType}}
   retry_wait {{.RetryWait}}
   retry_max_interval {{.RetryMaxInterval}}
-  retry_forever true
+  {{.RetryTimeout}}
   # the systemd journald 0.0.8 input plugin will just throw away records if the buffer
   # queue limit is hit - 'block' will halt further reads and keep retrying to flush the
   # buffer to the remote - default is 'block' because in_tail handles that case
@@ -768,19 +874,37 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
   port {{.Port}}
   verify_es_version_at_startup false
 {{- if .Target.Secret }}
+{{- if .IsTLS }}
   scheme https
   ssl_version TLSv1_2
 {{- else }}
   scheme http
 {{- end }}
+
+{{- if .HasUsernamePassword }}
+{{ with $path := .SecretPath "username" -}}
+  user "#{File.exists?('{{ $path }}') ? open('{{ $path }}','r') do |f|f.read end : ''}"
+{{ end -}}
+{{ with $path := .SecretPath "password" -}}
+  password "#{File.exists?('{{ $path }}') ? open('{{ $path }}','r') do |f|f.read end : ''}"
+{{ end -}}
+{{- end}}
+
+{{- if .HasTLSKeyAndCrt }}
+  client_key '{{ .SecretPath "tls.key"}}'
+  client_cert '{{ .SecretPath "tls.crt"}}'
+{{- end }}
+
+{{- if .HasCABundle }}
+  ca_file '{{ .SecretPath "ca-bundle.crt"}}'
+{{- end }}
+
+{{- else}}
+  scheme http
+{{- end }}
   target_index_key viaq_index_name
   id_key viaq_msg_id
   remove_keys viaq_index_name
-{{- if .Target.Secret }}
-  client_key '{{ .SecretPath "tls.key"}}'
-  client_cert '{{ .SecretPath "tls.crt"}}'
-  ca_file '{{ .SecretPath "ca-bundle.crt"}}'
-{{- end }}
   type_name _doc
 {{- if .Hints.Has "include_retry_tag" }}
   retry_tag {{.RetryTag}}
@@ -799,13 +923,15 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
     @type file
     path '{{.BufferPath}}'
     flush_mode {{.FlushMode}}
+    {{- if (eq .FlushMode "interval")}}
     flush_interval {{.FlushInterval}}
+    {{- end}}
     flush_thread_count {{.FlushThreadCount}}
-    flush_at_shutdown true
+
     retry_type {{.RetryType}}
     retry_wait {{.RetryWait}}
     retry_max_interval {{.RetryMaxInterval}}
-    retry_forever true
+    {{.RetryTimeout}}
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
     total_limit_size {{.TotalLimitSize}}
     chunk_limit_size {{.ChunkLimitSize}}
@@ -829,14 +955,14 @@ const storeSyslogTemplateOld = `{{- define "storeSyslogOld" -}}
 //      hostname ${hostname}
 const storeSyslogTemplate = `{{- define "storeSyslog" -}}
 <store>
-	@type remote_syslog
-	@id {{.StoreID}}
-	host {{.Host}}
-	port {{.Port}}
-	rfc {{.Rfc}}
-	facility {{.Facility}}
+  @type remote_syslog
+  @id {{.StoreID}}
+  host {{.Host}}
+  port {{.Port}}
+  rfc {{.Rfc}}
+  facility {{.Facility}}
     severity {{.Severity}}
-	{{if .Target.Syslog.AppName -}}
+	{{if .HasAppName -}}
 	appname {{.AppName}}
 	{{end -}}
 	{{if .Target.Syslog.MsgID -}}
@@ -845,7 +971,7 @@ const storeSyslogTemplate = `{{- define "storeSyslog" -}}
 	{{if .Target.Syslog.ProcID -}}
 	procid {{.ProcID}}
 	{{end -}}
-	{{if .Target.Syslog.Tag -}}
+	{{if .HasTag -}}
 	program {{.Tag}}
 	{{end -}}
 	protocol {{.Protocol}}
@@ -866,22 +992,28 @@ const storeSyslogTemplate = `{{- define "storeSyslog" -}}
 {{ end -}}
 
 {{if .PayloadKey -}}
-	<format>
-	  @type single_value
-	  message_key {{.PayloadKey}}
-	</format>
+  <format>
+    @type single_json_value
+    message_key {{.PayloadKey}}
+  </format>
+{{else -}}
+<format>
+  @type json
+</format>
 {{end -}}
   <buffer {{.ChunkKeys}}>
     @type file
     path '{{.BufferPath}}'
     flush_mode {{.FlushMode}}
+    {{- if (eq .FlushMode "interval")}}
     flush_interval {{.FlushInterval}}
+    {{- end}}
     flush_thread_count {{.FlushThreadCount}}
-    flush_at_shutdown true
+
     retry_type {{.RetryType}}
     retry_wait {{.RetryWait}}
     retry_max_interval {{.RetryMaxInterval}}
-    retry_forever true
+    {{.RetryTimeout}}
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
     total_limit_size {{.TotalLimitSize}}
     chunk_limit_size {{.ChunkLimitSize}}
@@ -896,12 +1028,29 @@ brokers {{.Brokers}}
 default_topic {{.Topic}}
 use_event_time true
 {{ if .Target.Secret -}}
+{{ if and (.SecretPathIfFound "username") (.SecretPathIfFound "password") -}}
+{{ with $path := .SecretPath "username" -}}
+sasl_plain_username "#{File.exists?('{{ $path }}') ? open('{{ $path }}','r') do |f|f.read end : ''}"
+{{ end -}}
+{{ with $path := .SecretPath "password" -}}
+sasl_plain_password "#{File.exists?('{{ $path }}') ? open('{{ $path }}','r') do |f|f.read end : ''}"
+{{ end -}}
+{{ end -}}
+{{ if not (.SecretPathIfFound "sasl_over_ssl") -}}
+sasl_over_ssl false
+{{ else }}
+sasl_over_ssl true
+{{ end -}}
+{{ if and (.SecretPathIfFound "tls.crt") (.SecretPathIfFound "tls.key") -}}
 {{ $tlsCert := .SecretPath "tls.crt" }}
 {{ $tlsKey := .SecretPath "tls.key" }}
-ssl_ca_cert '{{ .SecretPath "ca-bundle.crt"}}'
 ssl_client_cert "#{File.exist?('{{ $tlsCert }}') ? '{{ $tlsCert }}' : nil}"
 ssl_client_cert_key "#{File.exist?('{{ $tlsKey }}') ? '{{ $tlsKey }}' : nil}"
 {{ end -}}
+{{ if .SecretPathIfFound "ca-bundle.crt" -}}
+ssl_ca_cert '{{ .SecretPath "ca-bundle.crt"}}'
+{{ end -}}
+{{ end -}}
 <format>
   @type json
 </format>
@@ -909,13 +1058,15 @@ ssl_client_cert_key "#{File.exist?('{{ $tlsKey }}') ? '{{ $tlsKey }}' : nil}"
   @type file
   path '{{.BufferPath}}'
   flush_mode {{.FlushMode}}
+  {{- if (eq .FlushMode "interval")}}
   flush_interval {{.FlushInterval}}
+  {{- end}}
   flush_thread_count {{.FlushThreadCount}}
-  flush_at_shutdown true
+
   retry_type {{.RetryType}}
   retry_wait {{.RetryWait}}
   retry_max_interval {{.RetryMaxInterval}}
-  retry_forever true
+  {{.RetryTimeout}}
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
   total_limit_size {{.TotalLimitSize}}
   chunk_limit_size {{.ChunkLimitSize}}
@@ -923,3 +1074,58 @@ ssl_client_cert_key "#{File.exist?('{{ $tlsKey }}') ? '{{ $tlsKey }}' : nil}"
 </buffer>
 {{- end}}
 `
+
+const outputLabelLokiTemplate = `{{- define "outputLabelLokiTemplate" -}}
+<label {{.LabelName}}>
+  <filter **>
+    @type record_modifier
+    <record>{{.LokiLabelFilter}}
+    </record>
+  </filter>
+
+  <match **>
+    @type loki
+    line_format json
+    url {{.URLBase}}
+{{ with .LokiTenantKeys -}}
+     tenant ${record.dig("{{stringsJoin . "\",\""}}")}
+{{ end -}}
+{{ with.SecretPath "username" -}}
+    username "#{File.read('{{ . }}') rescue nil}"
+{{ end -}}
+{{ with .SecretPath "password" -}}
+    password "#{File.read('{{ . }}') rescue nil}"
+{{ end -}}
+{{ with .SecretPathIfFound "tls.key" -}}
+    key "{{ . }}"
+{{ end -}}
+{{ with .SecretPathIfFound "tls.crt" -}}
+    cert "{{ . }}"
+{{ end -}}
+{{ with .SecretPathIfFound "ca-bundle.crt" -}}
+    ca_cert "{{ . }}"
+{{ end -}}
+    <label>{{.LokiLabel}}
+    </label>
+		<buffer>
+      @type file
+			path '{{.BufferPath}}'
+			flush_mode {{.FlushMode}}
+            {{- if (eq .FlushMode "interval")}}
+            flush_interval {{.FlushInterval}}
+            {{- end}}
+			flush_thread_count {{.FlushThreadCount}}
+
+			retry_type {{.RetryType}}
+			retry_wait {{.RetryWait}}
+			retry_max_interval {{.RetryMaxInterval}}
+			{{.RetryTimeout}}
+			queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+			total_limit_size {{.TotalLimitSize}}
+			chunk_limit_size {{.ChunkLimitSize}}
+			overflow_action {{.OverflowAction}}
+		</buffer>
+  </match>
+</label>
+{{- end}}
+`
