@@ -1,6 +1,7 @@
 package outputs
 
 import (
+	"github.com/openshift/cluster-logging-operator/test/framework/functional"
 	"path"
 
 	"github.com/ViaQ/logerr/log"
@@ -8,7 +9,6 @@ import (
 	. "github.com/onsi/gomega"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
-	"github.com/openshift/cluster-logging-operator/test/functional"
 	"github.com/openshift/cluster-logging-operator/test/helpers/types"
 	"github.com/openshift/cluster-logging-operator/test/matchers"
 	"github.com/openshift/cluster-logging-operator/test/runtime"
@@ -102,7 +102,7 @@ output {
 
 	Context("when sending to Logstash using fluent's forward protocol", func() {
 		It("should  be compatible", func() {
-			raw, err := framework.ReadApplicationLogsFrom(logging.OutputTypeFluentdForward)
+			raw, err := framework.ReadRawApplicationLogsFrom(logging.OutputTypeFluentdForward)
 			Expect(err).To(BeNil(), "Expected no errors reading the logs")
 			Expect(raw).To(Not(BeEmpty()))
 
